Changelog
=========

Changes for the upcoming release can be found in the `"changelog.d" directory <https://github.com/python-mario/mario-addons/tree/master/changelog.d>`_ in our repository.

..
   Do *NOT* add changelog entries here!

   This changelog is managed by towncrier and is compiled at release time.

   See https://www.mario-addons.readthedocs.org/en/latest/contributing.html#changelog for details.

.. towncrier release notes start

0.1.29 (2019-07-30)
-------------------


No significant changes.


----


0.1.26 (2019-07-29)
-------------------


Backward-incompatible Changes
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

- ``walk -t`` no longer uses ``eval`` on the left-hand side of the equal sign. That value can only refer to a type by name.
  `#47 <https://github.com/python-mario/mario-addons/issues/47>`_


----


0.1.0 (2019-07-17)
------------------

Changes
^^^^^^^

- First release on PyPI.

---
